@@ -1,4 +1,4 @@
 from schema_registry.client.client import SchemaRegistryClient
-from schema_registry.client import load, errors
+from schema_registry.client import schema, errors
 
 __all__ = ["SchemaRegistryClient"]
